@@ -6,9 +6,9 @@ use strict;
 
 our @ISA = qw( Exporter );
 
-our @EXPORT = qw( LoadArgs LoadPatterns ClearPatterns Process );
+our @EXPORT = qw( LoadArgs LoadPatterns ClearPatterns GetPatterns Process );
 
-our $VERSION = "1.5";
+our $VERSION = "1.6";
 
 
 sub new
@@ -109,6 +109,13 @@ sub ClearPatterns
 }
 
 
+sub GetPatterns
+{
+    my $self = shift;
+    $self->{ Patterns };
+}
+
+
 sub FindPositionsOfTags
 {
     my ( $positions, $patterns, $string_ref ) = @_;
@@ -292,6 +299,8 @@ Term::Highlight - Perl module to highlight regexp patterns on terminals
 
 =item $obj->ClearPatterns( );
 
+=item $obj->GetPatterns( );
+
 =item $obj->Process( \$string );
 
 =back
@@ -321,6 +330,10 @@ Loads patterns to be processed.
 
 clears the loaded patterns.
 
+=item B<GetPatterns>
+
+returns a reference to the loaded patterns.
+
 =item B<LoadArgs>
 
 expects an array of references to strings.
